You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@wicket.apache.org by jc...@apache.org on 2007/04/10 20:16:39 UTC

svn commit: r527232 [7/28] - in /incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src: main/java/ main/java/org/ main/java/org/apache/ main/java/org/apache/wicket/ main/java/org/apache/wicket/ajax/ main/java/org/apache/wicket/ajax/calldecorator/ mai...

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/Form.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/Form.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/Form.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/Form.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/Form.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/Form.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/Form.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.HashMap;
 import java.util.Iterator;
@@ -23,37 +23,37 @@
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.Component;
+import org.apache.wicket.IRequestTarget;
+import org.apache.wicket.MarkupContainer;
+import org.apache.wicket.Page;
+import org.apache.wicket.Request;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.html.border.Border;
+import org.apache.wicket.markup.html.form.persistence.CookieValuePersister;
+import org.apache.wicket.markup.html.form.persistence.IValuePersister;
+import org.apache.wicket.markup.html.form.upload.FileUploadField;
+import org.apache.wicket.markup.html.form.validation.IFormValidator;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.model.Model;
+import org.apache.wicket.protocol.http.RequestUtils;
+import org.apache.wicket.protocol.http.WebRequest;
+import org.apache.wicket.protocol.http.WebRequestCycle;
+import org.apache.wicket.request.IRequestCycleProcessor;
+import org.apache.wicket.request.RequestParameters;
+import org.apache.wicket.request.target.component.listener.ListenerInterfaceRequestTarget;
+import org.apache.wicket.util.lang.Bytes;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.string.interpolator.MapVariableInterpolator;
+import org.apache.wicket.util.upload.FileUploadException;
+import org.apache.wicket.util.upload.FileUploadBase.SizeLimitExceededException;
+import org.apache.wicket.util.value.ValueMap;
 
-import wicket.Component;
-import wicket.IRequestTarget;
-import wicket.MarkupContainer;
-import wicket.Page;
-import wicket.Request;
-import wicket.RequestCycle;
-import wicket.WicketRuntimeException;
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupStream;
-import wicket.markup.html.WebMarkupContainer;
-import wicket.markup.html.border.Border;
-import wicket.markup.html.form.persistence.CookieValuePersister;
-import wicket.markup.html.form.persistence.IValuePersister;
-import wicket.markup.html.form.upload.FileUploadField;
-import wicket.markup.html.form.validation.IFormValidator;
-import wicket.model.IModel;
-import wicket.model.Model;
-import wicket.protocol.http.RequestUtils;
-import wicket.protocol.http.WebRequest;
-import wicket.protocol.http.WebRequestCycle;
-import wicket.request.IRequestCycleProcessor;
-import wicket.request.RequestParameters;
-import wicket.request.target.component.listener.ListenerInterfaceRequestTarget;
-import wicket.util.lang.Bytes;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.Strings;
-import wicket.util.string.interpolator.MapVariableInterpolator;
-import wicket.util.upload.FileUploadException;
-import wicket.util.upload.FileUploadBase.SizeLimitExceededException;
-import wicket.util.value.ValueMap;
 
 /**
  * Base class for forms. To implement a form, subclass this class, add
@@ -93,9 +93,9 @@
  * </p>
  * 
  * Form for handling (file) uploads with multipart requests is supported by
- * callign setMultiPart(true) ( although wicket will try to automatically detect
+ * callign setMultiPart(true) ( although org.apache.wicket will try to automatically detect
  * this for you ). Use this with
- * {@link wicket.markup.html.form.upload.FileUploadField} components. You can
+ * {@link org.apache.wicket.markup.html.form.upload.FileUploadField} components. You can
  * attach mutliple FileUploadField components for muliple file uploads.
  * <p>
  * In case of an upload error two resource keys are available to specify error
@@ -154,7 +154,7 @@
 	static abstract class ValidationVisitor implements FormComponent.IVisitor
 	{
 		/**
-		 * @see wicket.markup.html.form.FormComponent.IVisitor#formComponent(wicket.markup.html.form.IFormProcessingListener)
+		 * @see org.apache.wicket.markup.html.form.FormComponent.IVisitor#formComponent(org.apache.wicket.markup.html.form.IFormProcessingListener)
 		 */
 		public Object formComponent(IFormProcessingListener component)
 		{
@@ -237,7 +237,7 @@
 	 *            See Component
 	 * @param model
 	 *            See Component
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public Form(final String id, IModel model)
 	{
@@ -400,7 +400,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#onDetach()
+	 * @see org.apache.wicket.Component#onDetach()
 	 */
 	protected void onDetach()
 	{
@@ -500,7 +500,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#setVersioned(boolean)
+	 * @see org.apache.wicket.Component#setVersioned(boolean)
 	 */
 	public final Component setVersioned(final boolean isVersioned)
 	{
@@ -520,7 +520,7 @@
 	/**
 	 * Method made final because we want to ensure users call setVersioned.
 	 * 
-	 * @see wicket.Component#isVersioned()
+	 * @see org.apache.wicket.Component#isVersioned()
 	 */
 	public boolean isVersioned()
 	{
@@ -712,7 +712,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#internalOnModelChanged()
+	 * @see org.apache.wicket.Component#internalOnModelChanged()
 	 */
 	protected void internalOnModelChanged()
 	{
@@ -829,7 +829,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#onComponentTag(ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(ComponentTag)
 	 */
 	protected void onComponentTag(final ComponentTag tag)
 	{
@@ -895,7 +895,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#onRender(MarkupStream)
+	 * @see org.apache.wicket.Component#onRender(MarkupStream)
 	 */
 	protected void onRender(final MarkupStream markupStream)
 	{
@@ -970,7 +970,7 @@
 	 * Update the model of all form components using the fields that were sent
 	 * with the current request.
 	 * 
-	 * @see wicket.markup.html.form.FormComponent#updateModel()
+	 * @see org.apache.wicket.markup.html.form.FormComponent#updateModel()
 	 */
 	protected final void updateFormComponentModels()
 	{
@@ -1215,7 +1215,7 @@
 	 * to the FormComponent automatically when the page is visited by the user
 	 * next time.
 	 * 
-	 * @see wicket.markup.html.form.FormComponent#updateModel()
+	 * @see org.apache.wicket.markup.html.form.FormComponent#updateModel()
 	 */
 	private void persistFormComponentData()
 	{
@@ -1254,7 +1254,7 @@
 
 	/**
 	 * Method for dispatching/calling a interface on a page from the given url.
-	 * Used by {@link wicket.markup.html.form.Form#onFormSubmitted()} for
+	 * Used by {@link org.apache.wicket.markup.html.form.Form#onFormSubmitted()} for
 	 * dispatching events
 	 * 
 	 * @param page
@@ -1348,7 +1348,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getLocale()
+		 * @see org.apache.wicket.Request#getLocale()
 		 */
 		public Locale getLocale()
 		{
@@ -1356,7 +1356,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getParameter(java.lang.String)
+		 * @see org.apache.wicket.Request#getParameter(java.lang.String)
 		 */
 		public String getParameter(String key)
 		{
@@ -1364,7 +1364,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getParameterMap()
+		 * @see org.apache.wicket.Request#getParameterMap()
 		 */
 		public Map getParameterMap()
 		{
@@ -1372,7 +1372,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getParameters(java.lang.String)
+		 * @see org.apache.wicket.Request#getParameters(java.lang.String)
 		 */
 		public String[] getParameters(String key)
 		{
@@ -1385,7 +1385,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getPath()
+		 * @see org.apache.wicket.Request#getPath()
 		 */
 		public String getPath()
 		{
@@ -1393,7 +1393,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getRelativeURL()
+		 * @see org.apache.wicket.Request#getRelativeURL()
 		 */
 		public String getRelativeURL()
 		{
@@ -1406,7 +1406,7 @@
 		}
 
 		/**
-		 * @see wicket.Request#getURL()
+		 * @see org.apache.wicket.Request#getURL()
 		 */
 		public String getURL()
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponent.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponent.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponent.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponent.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponent.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponent.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponent.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.text.Format;
 import java.text.SimpleDateFormat;
@@ -25,27 +25,28 @@
 import java.util.Locale;
 import java.util.Map;
 
-import wicket.Component;
-import wicket.Localizer;
-import wicket.Page;
-import wicket.WicketRuntimeException;
-import wicket.markup.ComponentTag;
-import wicket.markup.html.WebMarkupContainer;
-import wicket.model.IComponentAssignedModel;
-import wicket.model.IModel;
-import wicket.util.convert.ConversionException;
-import wicket.util.convert.IConverter;
-import wicket.util.lang.Classes;
-import wicket.util.string.PrependingStringBuffer;
-import wicket.util.string.StringList;
-import wicket.util.string.Strings;
-import wicket.util.string.interpolator.MapVariableInterpolator;
-import wicket.validation.IErrorMessageSource;
-import wicket.validation.IValidatable;
-import wicket.validation.IValidationError;
-import wicket.validation.IValidator;
-import wicket.validation.ValidationError;
-import wicket.version.undo.Change;
+import org.apache.wicket.Component;
+import org.apache.wicket.Localizer;
+import org.apache.wicket.Page;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.model.IComponentAssignedModel;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.util.convert.ConversionException;
+import org.apache.wicket.util.convert.IConverter;
+import org.apache.wicket.util.lang.Classes;
+import org.apache.wicket.util.string.PrependingStringBuffer;
+import org.apache.wicket.util.string.StringList;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.util.string.interpolator.MapVariableInterpolator;
+import org.apache.wicket.validation.IErrorMessageSource;
+import org.apache.wicket.validation.IValidatable;
+import org.apache.wicket.validation.IValidationError;
+import org.apache.wicket.validation.IValidator;
+import org.apache.wicket.validation.ValidationError;
+import org.apache.wicket.version.undo.Change;
+
 
 /**
  * An HTML form component knows how to validate itself. Validators that
@@ -94,7 +95,7 @@
 	public static abstract class AbstractVisitor implements IVisitor
 	{
 		/**
-		 * @see wicket.markup.html.form.FormComponent.IVisitor#formComponent(wicket.markup.html.form.FormComponent)
+		 * @see org.apache.wicket.markup.html.form.FormComponent.IVisitor#formComponent(org.apache.wicket.markup.html.form.FormComponent)
 		 */
 		public Object formComponent(IFormProcessingListener component)
 		{
@@ -120,7 +121,7 @@
 		private final boolean required = isRequired();
 
 		/**
-		 * @see wicket.version.undo.Change#undo()
+		 * @see org.apache.wicket.version.undo.Change#undo()
 		 */
 		public void undo()
 		{
@@ -180,7 +181,7 @@
 	private Object validators = null;
 
 	/**
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public FormComponent(final String id)
 	{
@@ -191,7 +192,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public FormComponent(final String id, IModel model)
 	{
@@ -934,7 +935,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#internalOnModelChanged()
+	 * @see org.apache.wicket.Component#internalOnModelChanged()
 	 */
 	protected void internalOnModelChanged()
 	{
@@ -948,7 +949,7 @@
 	 *
 	 * @param tag
 	 *            Tag to modify
-	 * @see wicket.Component#onComponentTag(ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(ComponentTag)
 	 */
 	protected void onComponentTag(final ComponentTag tag)
 	{
@@ -1127,7 +1128,7 @@
 	{
 
 		/**
-		 * @see wicket.validation.IValidatable#error(wicket.validation.IValidationError)
+		 * @see org.apache.wicket.validation.IValidatable#error(org.apache.wicket.validation.IValidationError)
 		 */
 		public void error(IValidationError error)
 		{
@@ -1135,7 +1136,7 @@
 		}
 
 		/**
-		 * @see wicket.validation.IValidatable#getValue()
+		 * @see org.apache.wicket.validation.IValidatable#getValue()
 		 */
 		public Object getValue()
 		{
@@ -1159,7 +1160,7 @@
 	{
 
 		/**
-		 * @see wicket.validation.IErrorMessageSource#getMessage(java.lang.String)
+		 * @see org.apache.wicket.validation.IErrorMessageSource#getMessage(java.lang.String)
 		 */
 		public String getMessage(String key)
 		{
@@ -1291,7 +1292,7 @@
 
 
 		/**
-		 * @see wicket.validation.IErrorMessageSource#substitute(java.lang.String,
+		 * @see org.apache.wicket.validation.IErrorMessageSource#substitute(java.lang.String,
 		 *      java.util.Map)
 		 */
 		public String substitute(String string, Map vars) throws IllegalStateException
@@ -1301,7 +1302,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.IFormProcessingListener#processChildren(boolean)
+	 * @see org.apache.wicket.markup.html.form.IFormProcessingListener#processChildren(boolean)
 	 */
 	public boolean processChildren()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponentLabel.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponentLabel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponentLabel.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponentLabel.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponentLabel.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponentLabel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponentLabel.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.ComponentTag;
-import wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.html.WebMarkupContainer;
 
 /**
  * A component that represents html label tag. This component will automatically

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponentPanel.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponentPanel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponentPanel.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponentPanel.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponentPanel.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/FormComponentPanel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/FormComponentPanel.java Tue Apr 10 11:15:14 2007
@@ -14,20 +14,20 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupStream;
-import wicket.markup.html.ContainerWithAssociatedMarkupHelper;
-import wicket.markup.html.HeaderPartContainer;
-import wicket.markup.html.IHeaderPartContainerProvider;
-import wicket.markup.html.internal.HtmlHeaderContainer;
-import wicket.markup.html.panel.Panel;
-import wicket.markup.parser.XmlTag;
-import wicket.model.IModel;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.markup.html.ContainerWithAssociatedMarkupHelper;
+import org.apache.wicket.markup.html.HeaderPartContainer;
+import org.apache.wicket.markup.html.IHeaderPartContainerProvider;
+import org.apache.wicket.markup.html.internal.HtmlHeaderContainer;
+import org.apache.wicket.markup.html.panel.Panel;
+import org.apache.wicket.markup.parser.XmlTag;
+import org.apache.wicket.model.IModel;
 
 /**
- * Panel (has it's own markup, defined between <wicket:panel> tags), that can
+ * Panel (has it's own markup, defined between <org.apache.wicket:panel> tags), that can
  * act as a form component. It typically wouldn't receive any input yourself,
  * and often you can get by with nesting form components in panels proper.
  * However, using this panel can help you with building components act to the
@@ -81,9 +81,9 @@
  * With this markup:
  * 
  * <pre>
- *   &lt;wicket:panel&gt;
+ *   &lt;org.apache.wicket:panel&gt;
  *     &lt;input type=&quot;text&quot; wicket:id=&quot;left&quot; size=&quot;2&quot; /&gt; * &lt;input type=&quot;text&quot; wicket:id=&quot;right&quot; size=&quot;2&quot; /&gt;
- *   &lt;/wicket:panel&gt;
+ *   &lt;/org.apache.wicket:panel&gt;
  * </pre>
  * 
  * Which could be used, for example as:
@@ -139,7 +139,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.IHeaderPartContainerProvider#newHeaderPartContainer(java.lang.String,
+	 * @see org.apache.wicket.markup.html.IHeaderPartContainerProvider#newHeaderPartContainer(java.lang.String,
 	 *      java.lang.String)
 	 */
 	public HeaderPartContainer newHeaderPartContainer(final String id, final String scope)
@@ -148,9 +148,9 @@
 	}
 
 	/**
-	 * Check the associated markup file for a wicket header tag
+	 * Check the associated markup file for a org.apache.wicket header tag
 	 * 
-	 * @see wicket.Component#renderHead(wicket.markup.html.internal.HtmlHeaderContainer)
+	 * @see org.apache.wicket.Component#renderHead(org.apache.wicket.markup.html.internal.HtmlHeaderContainer)
 	 */
 	public void renderHead(HtmlHeaderContainer container)
 	{
@@ -166,7 +166,7 @@
 
 	/**
 	 * 
-	 * @see wicket.Component#onComponentTag(wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(org.apache.wicket.markup.ComponentTag)
 	 */
 	protected void onComponentTag(final ComponentTag tag)
 	{
@@ -183,14 +183,14 @@
 
 	/**
 	 * 
-	 * @see wicket.Component#onComponentTagBody(wicket.markup.MarkupStream,
-	 *      wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTagBody(org.apache.wicket.markup.MarkupStream,
+	 *      org.apache.wicket.markup.ComponentTag)
 	 */
 	protected void onComponentTagBody(final MarkupStream markupStream, final ComponentTag openTag)
 	{
 		// Render the associated markup
 		renderAssociatedMarkup("panel",
-				"Markup for a panel component has to contain part '<wicket:panel>'");
+				"Markup for a panel component has to contain part '<org.apache.wicket:panel>'");
 
 		if (this.wasOpenCloseTag == false)
 		{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/HiddenField.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/HiddenField.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/HiddenField.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/HiddenField.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/HiddenField.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/HiddenField.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/HiddenField.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.model.IModel;
+import org.apache.wicket.model.IModel;
 
 /**
  * TextField doesn't permit the html <input type='hidden'> so this is a simple
@@ -81,7 +81,7 @@
 	 *            the model
 	 * @param type
 	 *            the type to use when updating the model for this text field
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public HiddenField(String id, IModel model, Class type)
 	{
@@ -89,7 +89,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.TextField#getInputType()
+	 * @see org.apache.wicket.markup.html.form.TextField#getInputType()
 	 */
 	protected String getInputType()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IChoiceRenderer.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IChoiceRenderer.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IChoiceRenderer.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IChoiceRenderer.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IChoiceRenderer.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IChoiceRenderer.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IChoiceRenderer.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * Renders one choice. Seperates the 'id' values used for internal

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormProcessingListener.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormProcessingListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormProcessingListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormProcessingListener.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormProcessingListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormProcessingListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormProcessingListener.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 /**
  * Listener interface that is called when a form is processed.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormSubmitListener.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormSubmitListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormSubmitListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormSubmitListener.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormSubmitListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormSubmitListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormSubmitListener.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.IRequestListener;
-import wicket.RequestListenerInterface;
+import org.apache.wicket.IRequestListener;
+import org.apache.wicket.RequestListenerInterface;
 
 /**
  * Listener interface that is called when a form is submitted.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormSubmittingComponent.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormSubmittingComponent.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormSubmittingComponent.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormSubmittingComponent.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormSubmittingComponent.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IFormSubmittingComponent.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IFormSubmittingComponent.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 /**
  * Interface that must be implemented by components that are able to submit

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IOnChangeListener.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IOnChangeListener.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IOnChangeListener.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IOnChangeListener.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IOnChangeListener.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/IOnChangeListener.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/IOnChangeListener.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.IRequestListener;
-import wicket.RequestListenerInterface;
+import org.apache.wicket.IRequestListener;
+import org.apache.wicket.RequestListenerInterface;
 
 /**
  * Listener method for OnChange events of dropdown lists and onclick events of

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ImageButton.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ImageButton.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ImageButton.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ImageButton.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ImageButton.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ImageButton.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ImageButton.java Tue Apr 10 11:15:14 2007
@@ -14,14 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.IResourceListener;
-import wicket.ResourceReference;
-import wicket.markup.ComponentTag;
-import wicket.markup.html.WebResource;
-import wicket.markup.html.image.resource.DefaultButtonImageResource;
-import wicket.markup.html.image.resource.LocalizedImageResource;
+import org.apache.wicket.IResourceListener;
+import org.apache.wicket.ResourceReference;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.html.WebResource;
+import org.apache.wicket.markup.html.image.resource.DefaultButtonImageResource;
+import org.apache.wicket.markup.html.image.resource.LocalizedImageResource;
 
 /**
  * A button which renders itself as an image button resource.
@@ -41,7 +41,7 @@
 	private LocalizedImageResource localizedImageResource = new LocalizedImageResource(this);
 
 	/**
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public ImageButton(String id)
 	{
@@ -91,7 +91,7 @@
 	}
 
 	/**
-	 * @see wicket.IResourceListener#onResourceRequested()
+	 * @see org.apache.wicket.IResourceListener#onResourceRequested()
 	 */
 	public void onResourceRequested()
 	{
@@ -103,7 +103,7 @@
 	 * 
 	 * @param tag
 	 *            Tag to modify
-	 * @see wicket.Component#onComponentTag(ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(ComponentTag)
 	 */
 	protected final void onComponentTag(final ComponentTag tag)
 	{
@@ -114,7 +114,7 @@
 	}
 	
 	/**
-	 * @see wicket.markup.html.form.Button#getStatelessHint()
+	 * @see org.apache.wicket.markup.html.form.Button#getStatelessHint()
 	 */
 	protected boolean getStatelessHint()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ListChoice.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ListChoice.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ListChoice.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ListChoice.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ListChoice.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ListChoice.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ListChoice.java Tue Apr 10 11:15:14 2007
@@ -14,12 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.List;
 
-import wicket.markup.ComponentTag;
-import wicket.model.IModel;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.model.IModel;
+
 
 /**
  * Essentially a drop down choice that doesn't drop down. Instead, it scrolls
@@ -61,7 +62,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String)
 	 */
 	public ListChoice(final String id)
 	{
@@ -69,7 +70,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List)
 	 */
 	public ListChoice(final String id, final List choices)
 	{
@@ -83,7 +84,7 @@
 	 *			  The collection of values in the list
 	 * @param renderer
 	 * 			  See AbstractChoice 
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List,IChoiceRenderer)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List,IChoiceRenderer)
 	 */
 	public ListChoice(final String id, final List choices,final IChoiceRenderer renderer)
 	{
@@ -157,7 +158,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel)
 	 */
 	public ListChoice(String id, IModel choices)
 	{
@@ -165,7 +166,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel,IModel)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel,IModel)
 	 */
 	public ListChoice(String id, IModel model, IModel choices)
 	{
@@ -173,7 +174,7 @@
 	}
 	
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel,IChoiceRenderer)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel,IChoiceRenderer)
 	 */
 	public ListChoice(String id, IModel choices, IChoiceRenderer renderer)
 	{
@@ -182,7 +183,7 @@
 
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel, IModel,IChoiceRenderer)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel, IModel,IChoiceRenderer)
 	 */
 	public ListChoice(String id, IModel model, IModel choices, IChoiceRenderer renderer)
 	{
@@ -190,7 +191,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel, IModel,IChoiceRenderer)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, IModel, IModel,IChoiceRenderer)
 	 */
 	public ListChoice(String id, IModel model, IModel choices, IChoiceRenderer renderer, int maxRows)
 	{
@@ -222,7 +223,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#onComponentTag(ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(ComponentTag)
 	 */
 	protected final void onComponentTag(final ComponentTag tag)
 	{
@@ -231,7 +232,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.FormComponent#supportsPersistence()
+	 * @see org.apache.wicket.markup.html.form.FormComponent#supportsPersistence()
 	 */
 	protected final boolean supportsPersistence()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ListMultipleChoice.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ListMultipleChoice.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ListMultipleChoice.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ListMultipleChoice.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ListMultipleChoice.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ListMultipleChoice.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ListMultipleChoice.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -22,12 +22,13 @@
 import java.util.List;
 import java.util.StringTokenizer;
 
-import wicket.WicketRuntimeException;
-import wicket.markup.ComponentTag;
-import wicket.model.IModel;
-import wicket.util.convert.ConversionException;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.Strings;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.util.convert.ConversionException;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.Strings;
+
 
 /**
  * A multiple choice list component.
@@ -68,7 +69,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String)
 	 */
 	public ListMultipleChoice(final String id)
 	{
@@ -76,7 +77,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List)
 	 */
 	public ListMultipleChoice(final String id, final List choices)
 	{
@@ -92,7 +93,7 @@
 	 *            list of choices
 	 * @param maxRows
 	 *            the maximum number of visible rows.
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List)
 	 */
 	public ListMultipleChoice(final String id, final List choices, final int maxRows)
 	{
@@ -101,7 +102,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      List,IChoiceRenderer)
 	 */
 	public ListMultipleChoice(final String id, final List choices, final IChoiceRenderer renderer)
@@ -110,7 +111,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel, List)
 	 */
 	public ListMultipleChoice(final String id, IModel object, final List choices)
@@ -119,7 +120,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel, List,IChoiceRenderer)
 	 */
 	public ListMultipleChoice(final String id, IModel object, final List choices,
@@ -129,7 +130,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel)
 	 */
 	public ListMultipleChoice(String id, IModel choices)
@@ -138,7 +139,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel,IModel)
 	 */
 	public ListMultipleChoice(String id, IModel model, IModel choices)
@@ -147,7 +148,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel,IChoiceRenderer)
 	 */
 	public ListMultipleChoice(String id, IModel choices, IChoiceRenderer renderer)
@@ -157,7 +158,7 @@
 
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel, IModel,IChoiceRenderer)
 	 */
 	public ListMultipleChoice(String id, IModel model, IModel choices, IChoiceRenderer renderer)
@@ -208,7 +209,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.AbstractChoice#isSelected(Object,int,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#isSelected(Object,int,
 	 *      String)
 	 */
 	protected final boolean isSelected(Object choice, int index, String selected)
@@ -231,7 +232,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#onComponentTag(ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(ComponentTag)
 	 */
 	protected final void onComponentTag(final ComponentTag tag)
 	{
@@ -245,7 +246,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.FormComponent#convertValue(String[])
+	 * @see org.apache.wicket.markup.html.form.FormComponent#convertValue(String[])
 	 */
 	protected Object convertValue(String[] ids) throws ConversionException
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/PasswordTextField.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/PasswordTextField.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/PasswordTextField.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/PasswordTextField.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/PasswordTextField.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/PasswordTextField.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/PasswordTextField.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.model.IModel;
 
-import wicket.markup.ComponentTag;
-import wicket.model.IModel;
 
 /**
  * A password text field component. As you type, characters show up as asterisks
@@ -50,7 +50,7 @@
 	private boolean resetPassword = true;
 
 	/**
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public PasswordTextField(final String id)
 	{
@@ -59,7 +59,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public PasswordTextField(final String id, IModel model)
 	{
@@ -122,7 +122,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.FormComponent#setModelValue(java.lang.String[])
+	 * @see org.apache.wicket.markup.html.form.FormComponent#setModelValue(java.lang.String[])
 	 */
 	public final void setModelValue(String[] valueArray)
 	{
@@ -147,7 +147,7 @@
 	 * 
 	 * @param tag
 	 *            Tag to modify
-	 * @see wicket.Component#onComponentTag(ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(ComponentTag)
 	 */
 	protected final void onComponentTag(final ComponentTag tag)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/Radio.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/Radio.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/Radio.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/Radio.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/Radio.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/Radio.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/Radio.java Tue Apr 10 11:15:14 2007
@@ -14,22 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.Component;
-import wicket.WicketRuntimeException;
-import wicket.markup.ComponentTag;
-import wicket.markup.html.WebMarkupContainer;
-import wicket.model.IModel;
-import wicket.util.lang.Objects;
+import org.apache.wicket.Component;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.util.lang.Objects;
 
 /**
  * Component representing a single radio choice in a
- * wicket.markup.html.form.RadioGroup.
+ * org.apache.wicket.markup.html.form.RadioGroup.
  * 
  * Must be attached to an &lt;input type=&quot;radio&quot; ... &gt; markup.
  * 
- * @see wicket.markup.html.form.RadioGroup
+ * @see org.apache.wicket.markup.html.form.RadioGroup
  * 
  * @author Igor Vaynberg (ivaynberg@users.sf.net)
  * @author Sven Meier (svenmeier)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RadioChoice.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RadioChoice.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RadioChoice.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RadioChoice.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RadioChoice.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RadioChoice.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RadioChoice.java Tue Apr 10 11:15:14 2007
@@ -14,17 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.util.List;
 
-import wicket.Page;
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupStream;
-import wicket.model.IModel;
-import wicket.util.string.AppendingStringBuffer;
-import wicket.util.string.Strings;
-import wicket.version.undo.Change;
+import org.apache.wicket.Page;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.util.string.AppendingStringBuffer;
+import org.apache.wicket.util.string.Strings;
+import org.apache.wicket.version.undo.Change;
+
 
 /**
  * A choice subclass that shows choices in radio style.
@@ -75,7 +76,7 @@
 		}
 
 		/**
-		 * @see wicket.version.undo.Change#undo()
+		 * @see org.apache.wicket.version.undo.Change#undo()
 		 */
 		public void undo()
 		{
@@ -111,7 +112,7 @@
 		}
 
 		/**
-		 * @see wicket.version.undo.Change#undo()
+		 * @see org.apache.wicket.version.undo.Change#undo()
 		 */
 		public void undo()
 		{
@@ -136,8 +137,8 @@
 	 * 
 	 * @param id
 	 *            See Component
-	 * @see wicket.Component#Component(String)
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String)
+	 * @see org.apache.wicket.Component#Component(String)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String)
 	 */
 	public RadioChoice(final String id)
 	{
@@ -151,8 +152,8 @@
 	 *            See Component
 	 * @param choices
 	 *            The collection of choices in the radio choice
-	 * @see wicket.Component#Component(String)
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List)
+	 * @see org.apache.wicket.Component#Component(String)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String, List)
 	 */
 	public RadioChoice(final String id, final List choices)
 	{
@@ -168,8 +169,8 @@
 	 *            The rendering engine
 	 * @param choices
 	 *            The collection of choices in the radio choice
-	 * @see wicket.Component#Component(String)
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.Component#Component(String)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      List,IChoiceRenderer)
 	 */
 	public RadioChoice(final String id, final List choices, final IChoiceRenderer renderer)
@@ -186,8 +187,8 @@
 	 *            See Component
 	 * @param choices
 	 *            The collection of choices in the radio choice
-	 * @see wicket.Component#Component(String, IModel)
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel, List)
 	 */
 	public RadioChoice(final String id, IModel model, final List choices)
@@ -206,8 +207,8 @@
 	 *            The collection of choices in the radio choice
 	 * @param renderer
 	 *            The rendering engine
-	 * @see wicket.Component#Component(String, IModel)
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel, List,IChoiceRenderer)
 	 */
 	public RadioChoice(final String id, IModel model, final List choices,
@@ -223,8 +224,8 @@
 	 *            See Component
 	 * @param choices
 	 *            The collection of choices in the radio choice
-	 * @see wicket.Component#Component(String)
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.Component#Component(String)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel)
 	 */
 	public RadioChoice(String id, IModel choices)
@@ -242,9 +243,9 @@
 	 *            Component
 	 * @param choices
 	 *            The collection of choices in the radio choice
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel,IModel)
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public RadioChoice(String id, IModel model, IModel choices)
 	{
@@ -260,9 +261,9 @@
 	 *            The collection of choices in the radio choice
 	 * @param renderer
 	 *            The rendering engine
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel,IChoiceRenderer)
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public RadioChoice(String id, IModel choices, IChoiceRenderer renderer)
 	{
@@ -282,8 +283,8 @@
 	 *            The collection of choices in the radio choice
 	 * @param renderer
 	 *            The rendering engine
-	 * @see wicket.Component#Component(String, IModel)
-	 * @see wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
+	 * @see org.apache.wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.markup.html.form.AbstractChoice#AbstractChoice(String,
 	 *      IModel, IModel,IChoiceRenderer)
 	 */
 	public RadioChoice(String id, IModel model, IModel choices, IChoiceRenderer renderer)
@@ -292,7 +293,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.FormComponent#onComponentTag(wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.markup.html.form.FormComponent#onComponentTag(org.apache.wicket.markup.ComponentTag)
 	 */
 	protected void onComponentTag(ComponentTag tag)
 	{
@@ -303,7 +304,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.IOnChangeListener#onSelectionChanged()
+	 * @see org.apache.wicket.markup.html.form.IOnChangeListener#onSelectionChanged()
 	 */
 	public void onSelectionChanged()
 	{
@@ -346,7 +347,7 @@
 	}
 
 	/**
-	 * @see wicket.MarkupContainer#getStatelessHint()
+	 * @see org.apache.wicket.MarkupContainer#getStatelessHint()
 	 */
 	protected boolean getStatelessHint()
 	{
@@ -410,7 +411,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#onComponentTagBody(MarkupStream, ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTagBody(MarkupStream, ComponentTag)
 	 */
 	protected final void onComponentTagBody(final MarkupStream markupStream,
 			final ComponentTag openTag)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RadioGroup.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RadioGroup.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RadioGroup.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RadioGroup.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RadioGroup.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RadioGroup.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RadioGroup.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.Component;
-import wicket.WicketRuntimeException;
-import wicket.markup.html.WebMarkupContainer;
-import wicket.model.IModel;
-import wicket.util.convert.ConversionException;
+import org.apache.wicket.Component;
+import org.apache.wicket.WicketRuntimeException;
+import org.apache.wicket.markup.html.WebMarkupContainer;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.util.convert.ConversionException;
 
 /**
  * Component used to connect instances of Radio components into a group.
@@ -72,7 +72,7 @@
 	}
 
 	/**
-	 * @see wicket.MarkupContainer#getStatelessHint()
+	 * @see org.apache.wicket.MarkupContainer#getStatelessHint()
 	 */
 	protected boolean getStatelessHint()
 	{
@@ -85,7 +85,7 @@
 
 
 	/**
-	 * @see wicket.markup.html.form.FormComponent#convertValue(String[])
+	 * @see org.apache.wicket.markup.html.form.FormComponent#convertValue(String[])
 	 */
 	protected Object convertValue(String[] input) throws ConversionException
 	{
@@ -162,7 +162,7 @@
 	/**
 	 * Radio group does not support persistence through cookies
 	 * 
-	 * @see wicket.markup.html.form.FormComponent#supportsPersistence()
+	 * @see org.apache.wicket.markup.html.form.FormComponent#supportsPersistence()
 	 */
 	protected final boolean supportsPersistence()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RequiredTextField.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RequiredTextField.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RequiredTextField.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RequiredTextField.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RequiredTextField.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/RequiredTextField.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/RequiredTextField.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.model.IModel;
+import org.apache.wicket.model.IModel;
 
 /**
  * A text field which automatically adds a RequiredValidator. This is mainly for
@@ -29,7 +29,7 @@
 	private static final long serialVersionUID = 1L;
 	
 	/**
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public RequiredTextField(final String id)
 	{
@@ -47,7 +47,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public RequiredTextField(final String id, final IModel model)
 	{
@@ -62,7 +62,7 @@
 	 *            See Component
 	 * @param type
 	 *            The type to use when updating the model for this text field
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public RequiredTextField(final String id, IModel model, Class type)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/SimpleFormComponentLabel.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/SimpleFormComponentLabel.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/SimpleFormComponentLabel.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/SimpleFormComponentLabel.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/SimpleFormComponentLabel.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/SimpleFormComponentLabel.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/SimpleFormComponentLabel.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupStream;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupStream;
 
 /**
  * A form component label that replaces its body with the contents of
@@ -50,8 +50,8 @@
 	}
 
 	/**
-	 * @see wicket.Component#onComponentTagBody(wicket.markup.MarkupStream,
-	 *      wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTagBody(org.apache.wicket.markup.MarkupStream,
+	 *      org.apache.wicket.markup.ComponentTag)
 	 */
 	protected void onComponentTagBody(final MarkupStream markupStream, final ComponentTag openTag)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/StatelessForm.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/StatelessForm.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/StatelessForm.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/StatelessForm.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/StatelessForm.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/StatelessForm.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/StatelessForm.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.model.IModel;
+import org.apache.wicket.model.IModel;
 
 /**
  * This StatelessForm is the same as a normal form but with the statelesshint default to true.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/SubmitLink.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/SubmitLink.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/SubmitLink.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/SubmitLink.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/SubmitLink.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/SubmitLink.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/SubmitLink.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.ComponentTag;
-import wicket.model.IModel;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.model.IModel;
 
 /**
  * A link which can be used exactly like a Button to submit a Form. The href of
@@ -142,7 +142,7 @@
 	 * This method is here as a means to fall back on normal link
 	 * behavior when this link is not nested in a form. Not intended
 	 * to be called by clients directly.
-	 * @see wicket.markup.html.link.ILinkListener#onLinkClicked()
+	 * @see org.apache.wicket.markup.html.link.ILinkListener#onLinkClicked()
 	 */
 	public final void onLinkClicked()
 	{
@@ -151,7 +151,7 @@
 
 	/**
 	 * @inheritDoc
-	 * @see wicket.Component#onComponentTag(wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(org.apache.wicket.markup.ComponentTag)
 	 */
 	protected void onComponentTag(ComponentTag tag)
 	{
@@ -226,7 +226,7 @@
 	}	
 	
 	/**
-	 * @see wicket.markup.html.form.IFormSubmittingComponent#onSubmit()
+	 * @see org.apache.wicket.markup.html.form.IFormSubmittingComponent#onSubmit()
 	 */
 	public void onSubmit()
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/TextArea.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/TextArea.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/TextArea.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/TextArea.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/TextArea.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/TextArea.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/TextArea.java Tue Apr 10 11:15:14 2007
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.ComponentTag;
-import wicket.markup.MarkupStream;
-import wicket.model.IModel;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.MarkupStream;
+import org.apache.wicket.model.IModel;
 
 /**
  * Multi-row text editing component.
@@ -30,7 +30,7 @@
 	private static final long serialVersionUID = 1L;
 	
 	/**
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public TextArea(final String id)
 	{
@@ -38,7 +38,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public TextArea(final String id, final IModel model)
 	{
@@ -52,7 +52,7 @@
 	 *            The markup stream
 	 * @param openTag
 	 *            The open tag for the body
-	 * @see wicket.Component#onComponentTagBody(MarkupStream, ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTagBody(MarkupStream, ComponentTag)
 	 */
 	protected final void onComponentTagBody(final MarkupStream markupStream,
 			final ComponentTag openTag)

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/TextField.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/TextField.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/TextField.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/TextField.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/TextField.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/TextField.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/TextField.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
-import wicket.markup.ComponentTag;
-import wicket.model.IModel;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.model.IModel;
 
 /**
  * A simple text field.
@@ -29,7 +29,7 @@
 	private static final long serialVersionUID = 1L;
 	
 	/**
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public TextField(final String id)
 	{
@@ -49,7 +49,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public TextField(final String id, final IModel object)
 	{
@@ -63,7 +63,7 @@
 	 *            See Component
 	 * @param type
 	 *            The type to use when updating the model for this text field
-	 * @see wicket.Component#Component(String, IModel)
+	 * @see org.apache.wicket.Component#Component(String, IModel)
 	 */
 	public TextField(final String id, IModel model, Class type)
 	{
@@ -76,7 +76,7 @@
 	 * 
 	 * @param tag
 	 *            Tag to modify
-	 * @see wicket.Component#onComponentTag(ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(ComponentTag)
 	 */
 	protected void onComponentTag(final ComponentTag tag)
 	{

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ValidationErrorFeedback.java (from r527054, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ValidationErrorFeedback.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ValidationErrorFeedback.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ValidationErrorFeedback.java&r1=527054&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ValidationErrorFeedback.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/ValidationErrorFeedback.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/ValidationErrorFeedback.java Tue Apr 10 11:15:14 2007
@@ -14,13 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form;
+package org.apache.wicket.markup.html.form;
 
 import java.io.Serializable;
 
-import wicket.Component;
-import wicket.IClusterable;
-import wicket.validation.IValidationError;
+import org.apache.wicket.Component;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.validation.IValidationError;
+
 
 /**
  * This class is the parameter to {@link Component#error(Serializable)} instead

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersister.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/CookieValuePersister.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersister.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/CookieValuePersister.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersister.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/CookieValuePersister.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersister.java Tue Apr 10 11:15:14 2007
@@ -14,18 +14,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.persistence;
+package org.apache.wicket.markup.html.form.persistence;
 
 import javax.servlet.http.Cookie;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.wicket.RequestCycle;
+import org.apache.wicket.markup.html.form.FormComponent;
+import org.apache.wicket.protocol.http.WebRequest;
+import org.apache.wicket.protocol.http.WebResponse;
+import org.apache.wicket.util.time.Time;
 
-import wicket.RequestCycle;
-import wicket.markup.html.form.FormComponent;
-import wicket.protocol.http.WebRequest;
-import wicket.protocol.http.WebResponse;
-import wicket.util.time.Time;
 
 /**
  * This class implements IValuePersister by means of HTTP cookies.
@@ -41,7 +41,7 @@
 	private final static Log log = LogFactory.getLog(CookieValuePersister.class);
 
 	/**
-	 * @see wicket.markup.html.form.persistence.IValuePersister#clear(wicket.markup.html.form.FormComponent)
+	 * @see org.apache.wicket.markup.html.form.persistence.IValuePersister#clear(org.apache.wicket.markup.html.form.FormComponent)
 	 */
 	public void clear(final FormComponent component)
 	{
@@ -57,7 +57,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.persistence.IValuePersister#load(wicket.markup.html.form.FormComponent)
+	 * @see org.apache.wicket.markup.html.form.persistence.IValuePersister#load(org.apache.wicket.markup.html.form.FormComponent)
 	 */
 	public void load(final FormComponent component)
 	{
@@ -74,7 +74,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.persistence.IValuePersister#save(wicket.markup.html.form.FormComponent)
+	 * @see org.apache.wicket.markup.html.form.persistence.IValuePersister#save(org.apache.wicket.markup.html.form.FormComponent)
 	 */
 	public void save(final FormComponent component)
 	{
@@ -142,7 +142,7 @@
 	/**
 	 * Gets the cookie for a given persistent form component. The name of the
 	 * cookie will be the component's page relative path (@see
-	 * wicket.markup.html.form.FormComponent#getPageRelativePath()). Be reminded
+	 * org.apache.wicket.markup.html.form.FormComponent#getPageRelativePath()). Be reminded
 	 * that only if the cookie data have been provided by the client (browser),
 	 * they'll be accessible by the server.
 	 * 

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterSettings.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/CookieValuePersisterSettings.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterSettings.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/CookieValuePersisterSettings.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterSettings.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/CookieValuePersisterSettings.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/CookieValuePersisterSettings.java Tue Apr 10 11:15:14 2007
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.persistence;
+package org.apache.wicket.markup.html.form.persistence;
 
-import wicket.IClusterable;
+import org.apache.wicket.IClusterable;
 
 /**
  * This class provides default values that are used by the CookieValuePersister

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/IValuePersister.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/IValuePersister.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/IValuePersister.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/IValuePersister.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/IValuePersister.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/persistence/IValuePersister.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/persistence/IValuePersister.java Tue Apr 10 11:15:14 2007
@@ -14,10 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.persistence;
+package org.apache.wicket.markup.html.form.persistence;
 
-import wicket.IClusterable;
-import wicket.markup.html.form.FormComponent;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.markup.html.form.FormComponent;
 
 /**
  * Wicket users and developers should not need to care about where or how form

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/upload/FileUpload.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/upload/FileUpload.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/upload/FileUpload.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/upload/FileUpload.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/upload/FileUpload.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/upload/FileUpload.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/upload/FileUpload.java Tue Apr 10 11:15:14 2007
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.upload;
+package org.apache.wicket.markup.html.form.upload;
 
 import java.io.File;
 import java.io.IOException;
@@ -23,10 +23,11 @@
 import java.util.Iterator;
 import java.util.List;
 
-import wicket.IClusterable;
-import wicket.Session;
-import wicket.util.file.Files;
-import wicket.util.upload.FileItem;
+import org.apache.wicket.IClusterable;
+import org.apache.wicket.Session;
+import org.apache.wicket.util.file.Files;
+import org.apache.wicket.util.upload.FileItem;
+
 
 /**
  * Model for file uploads.

Copied: incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/upload/FileUploadField.java (from r527216, incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/upload/FileUploadField.java)
URL: http://svn.apache.org/viewvc/incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/upload/FileUploadField.java?view=diff&rev=527232&p1=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/upload/FileUploadField.java&r1=527216&p2=incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/upload/FileUploadField.java&r2=527232
==============================================================================
--- incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/wicket/markup/html/form/upload/FileUploadField.java (original)
+++ incubator/wicket/branches/wicket-1.x/jdk-1.4/wicket/src/main/java/org/apache/wicket/markup/html/form/upload/FileUploadField.java Tue Apr 10 11:15:14 2007
@@ -14,22 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package wicket.markup.html.form.upload;
+package org.apache.wicket.markup.html.form.upload;
 
 
-import wicket.Component;
-import wicket.Request;
-import wicket.markup.ComponentTag;
-import wicket.markup.html.form.FormComponent;
-import wicket.model.IModel;
-import wicket.protocol.http.IMultipartWebRequest;
-import wicket.util.upload.FileItem;
+import org.apache.wicket.Component;
+import org.apache.wicket.Request;
+import org.apache.wicket.markup.ComponentTag;
+import org.apache.wicket.markup.html.form.FormComponent;
+import org.apache.wicket.model.IModel;
+import org.apache.wicket.protocol.http.IMultipartWebRequest;
+import org.apache.wicket.util.upload.FileItem;
 
 /**
  * Form component that corresponds to a &lt;input type=&quot;file&quot;&gt;.
  * When a FileInput component is nested in a
  * {@link wicket.markup.html.form.Form}, that has multipart == true, its model
  * is updated with the {@link wicket.util.upload.FileItem}for this component.
  * 
  * @author Eelco Hillenius
  */
@@ -43,7 +43,7 @@
 	private transient FileUpload fileUpload;
 
 	/**
-	 * @see wicket.Component#Component(String)
+	 * @see org.apache.wicket.Component#Component(String)
 	 */
 	public FileUploadField(final String id)
 	{
@@ -92,7 +92,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#setModel(wicket.model.IModel)
+	 * @see org.apache.wicket.Component#setModel(org.apache.wicket.model.IModel)
 	 */
 	public Component setModel(IModel model)
 	{
@@ -101,7 +101,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.FormComponent#updateModel()
+	 * @see org.apache.wicket.markup.html.form.FormComponent#updateModel()
 	 */
 	public void updateModel()
 	{
@@ -114,7 +114,7 @@
 
 
 	/**
-	 * @see wicket.markup.html.form.FormComponent#getInputAsArray()
+	 * @see org.apache.wicket.markup.html.form.FormComponent#getInputAsArray()
 	 */
 	public String[] getInputAsArray()
 	{
@@ -125,7 +125,7 @@
 	}
 
 	/**
-	 * @see wicket.markup.html.form.FormComponent#isMultiPart()
+	 * @see org.apache.wicket.markup.html.form.FormComponent#isMultiPart()
 	 */
 	public boolean isMultiPart()
 	{
@@ -133,7 +133,7 @@
 	}
 
 	/**
-	 * @see wicket.Component#onComponentTag(wicket.markup.ComponentTag)
+	 * @see org.apache.wicket.Component#onComponentTag(org.apache.wicket.markup.ComponentTag)
 	 */
 	protected void onComponentTag(ComponentTag tag)
 	{
@@ -150,7 +150,7 @@
 	/**
 	 * FileInputs cannot be persisted; returns false.
 	 * 
-	 * @see wicket.markup.html.form.FormComponent#supportsPersistence()
+	 * @see org.apache.wicket.markup.html.form.FormComponent#supportsPersistence()
 	 */
 	protected boolean supportsPersistence()
 	{
@@ -161,7 +161,7 @@
 	 * Clean up at the end of the request. This means closing all inputstreams
 	 * which might have been opened from the fileUpload.
 	 * 
-	 * @see wicket.Component#onDetach()
+	 * @see org.apache.wicket.Component#onDetach()
 	 */
 	protected void onDetach()
 	{
@@ -14,22 +14,22 @@
  * Form component that corresponds to a &lt;input type=&quot;file&quot;&gt;.
  * When a FileInput component is nested in a
- * {@link wicket.markup.html.form.Form}, that has multipart == true, its model
- * is updated with the {@link wicket.util.upload.FileItem}for this component.
+ * {@link org.apache.wicket.markup.html.form.Form}, that has multipart == true, its model
+ * is updated with the {@link org.apache.wicket.util.upload.FileItem}for this component.
  * 
  * @author Eelco Hillenius